@@ -46,6 +46,7 @@ module HOpenPGP.Tools.Common (
   , spGetSigType
   , spGetPKAlgo
   , spGetHashAlgo
+  , spGetSCT
   , maybeR
 ) where
 
@@ -53,6 +54,7 @@ import Paths_hopenpgp_tools (version)
 import Data.Version (showVersion)
 
 import Codec.Encryption.OpenPGP.Fingerprint (eightOctetKeyID, fingerprint)
+import Codec.Encryption.OpenPGP.SignatureQualities (sigCT)
 import Codec.Encryption.OpenPGP.Types
 import Control.Lens ((^..))
 import Data.Binary (put)
@@ -189,6 +191,9 @@ spGetHashAlgo (SignaturePkt s) = fmap (fromIntegral . fromFVal) (sigHA s)
         sigHA _ = Nothing -- this includes v2 sigs, which don't seem to be specified in the RFCs but exist in the wild
 spGetHashAlgo _ = Nothing
 
+spGetSCT :: Pkt -> Maybe Integer
+spGetSCT (SignaturePkt s) = fmap fromIntegral (sigCT s)
+
 pUsingPKP :: Reader (Maybe PKPayload) a -> Reader Pkt a
 pUsingPKP = withReader grabPayload
     where
