@@ -30,7 +30,6 @@ import Control.Applicative (optional, (<|>))
 import Control.Arrow ((&&&))
 import Control.Lens ((^.), _1, _2, (^..))
 import Control.Monad.Trans.Resource (MonadResource, MonadThrow)
-import qualified Control.Monad.Trans.State.Lazy as S
 import qualified Data.Aeson as A
 import Data.Binary (get, put)
 import Data.Binary.Put (runPut)
@@ -290,7 +289,7 @@ doGraph o = do
         nonClusteredLabeledNodesParams = nonClusteredParams { fmtNode = \(_,l) -> [toLabel $ show (pretty l)] }
 
 buildMaps :: [TK] -> (KeyMaps, Int)
-buildMaps ks = S.execState (mapM_ mapsInsertions ks) (KeyMaps HashMap.empty HashMap.empty HashMap.empty, 0)
+buildMaps = foldr mapsInsertions (KeyMaps HashMap.empty HashMap.empty HashMap.empty, 0)
 
 -- FIXME: this presumes no keyID collisions in the input
 data KeyMaps = KeyMaps {
@@ -299,16 +298,14 @@ data KeyMaps = KeyMaps {
   , _i2f :: HashMap Int TwentyOctetFingerprint
 }
 
-mapsInsertions :: TK -> S.State (KeyMaps, Int) ()
-mapsInsertions tk = do
-    (KeyMaps k2f f2i i2f, i) <- S.get
+mapsInsertions :: TK -> (KeyMaps, Int) -> (KeyMaps, Int)
+mapsInsertions tk (KeyMaps k2f f2i i2f, i) =
     let fp = fingerprint (tk^.tkKey._1)
         keyids = rights . map eightOctetKeyID $ (tk ^.. biplate :: [PKPayload])
         i' = i + 1
         k2f' = foldr (\k m -> HashMap.insert k fp m) k2f keyids
         f2i' = HashMap.insert fp i' f2i
-        i2f' = HashMap.insert i' fp i2f
-    S.put (KeyMaps k2f' f2i' i2f', i')
+        i2f' = HashMap.insert i' fp i2f in (KeyMaps k2f' f2i' i2f', i')
 
 buildKeyGraph :: ((KeyMaps, Int), [TK]) -> Gr TwentyOctetFingerprint HashAlgorithm
 buildKeyGraph ((KeyMaps k2f f2i _, _), ks) = mkGraph nodes edges
