@@ -1,5 +1,5 @@
 -- hokey.hs: hOpenPGP key tool
--- Copyright © 2013-2018  Clint Adams
+-- Copyright © 2013-2019  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -31,9 +31,6 @@ import Codec.Encryption.OpenPGP.KeySelection (parseFingerprint)
 import Codec.Encryption.OpenPGP.Ontology (isCertRevocationSig, isCT, isKUF, isPHA, isPKBindingSig, isSKBindingSig)
 import Codec.Encryption.OpenPGP.Serialize ()
 import Codec.Encryption.OpenPGP.Types
-#if !MIN_VERSION_base(4,8,0)
-import Control.Applicative ((<$>),(<*>), pure)
-#endif
 import Control.Arrow ((***))
 import Control.Error.Util (hush)
 import Control.Lens ((^.), (&), _1, _2, mapped, over)
@@ -52,18 +49,15 @@ import Data.Conduit.Serialization.Binary (conduitGet, conduitPut)
 import qualified Data.Conduit.List as CL
 import Data.Conduit.OpenPGP.Keyring (conduitToTKsDropping)
 import Data.Foldable (find)
-import Data.List (elemIndex, findIndex, nub, sort, sortBy, intercalate)
+import Data.List (elemIndex, findIndex, nub, sort, sortOn, intercalate)
 import qualified Data.Map as Map
 import Data.Maybe (fromMaybe, mapMaybe, listToMaybe)
-#if !MIN_VERSION_base(4,8,0)
-import Data.Monoid (mconcat, Monoid(..))
-#endif
 #if !MIN_VERSION_base(4,9,0)
 import Data.Monoid ((<>))
 #else
 import Data.Semigroup ((<>), Semigroup)
 #endif
-import Data.Ord (comparing, Down(..))
+import Data.Ord (Down(..))
 import qualified Data.Set as Set
 import Data.Text (Text)
 import qualified Data.Text as T
@@ -236,7 +230,7 @@ checkKey mpt key = (\x -> x { keyBestOf = populateBestOf x, keyHasEncryptionCapa
                                                      (findRevocationReason sps))
         populateBestOf krep = Just (UIDReport <$> best . uidSelfSigHashAlgorithms <*> best . uidPreferredHashAlgorithms <*> best . uidKeyExpirationTimes <*> best . uidKeyUsageFlags <*> pure [] $ mconcat (justTheUIDRs krep))
         justTheUIDRs = map (decolorize . snd) . unFakeMap . keyUIDsAndUAts
-        best = take 1 . sortBy (comparing color)
+        best = take 1 . sortOn color
         decolorize (Colored _ _ x) = x
         colorizeUID u
             | '(' `elem` T.unpack u = Colored (Just Yellow) (Just "parenthesis in uid")  -- FIXME: be more discerning
@@ -250,7 +244,7 @@ checkKey mpt key = (\x -> x { keyBestOf = populateBestOf x, keyHasEncryptionCapa
         kufs s = map (colorizeKUFs s . (\(SigSubPacket _ (KeyFlags x)) -> x) . fromMaybe undefined . find isKUF . hasheds) . newestWith (any isKUF . hasheds)
         colorizeKUFs False x = uncurry Colored (if (Set.member EncryptStorageKey x || Set.member EncryptCommunicationsKey x) && (Set.member SignDataKey x || Set.member CertifyKeysKey x) then (Just Yellow, Just "both signing & encryption") else (Just Green, Nothing)) x
         colorizeKUFs True x = uncurry Colored (if Set.member CertifyKeysKey x then (Just Red, Just "certification-capable subkey") else (if (Set.member EncryptStorageKey x || Set.member EncryptCommunicationsKey x) && Set.member SignDataKey x then (Just Yellow, Just "both signing & encryption") else (Just Green, Nothing))) x
-        newestWith p = take 1 . sortBy (comparing (Down . take 1 . sigcts)) . filter p -- FIXME: this is terrible
+        newestWith p = take 1 . sortOn (Down . take 1 . sigcts) . filter p -- FIXME: this is terrible
         hasheds (SigV4 _ _ _ xs _ _ _) = xs
         hasheds _ = []
         checkSK :: TwentyOctetFingerprint -> (Pkt, [SignaturePayload]) -> SubkeyReport
