@@ -18,8 +18,8 @@
 -- You should have received a copy of the GNU Affero General Public License
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import Paths_hopenpgp_tools (version)
 import HOpenPGP.Tools.Common (banner, versioner, warranty, prependAuto)
+import HOpenPGP.Tools.Armor (doDeArmor)
 import HOpenPGP.Tools.Parser (parsePExp)
 import qualified Codec.Encryption.OpenPGP.ASCIIArmor as AA
 import Codec.Encryption.OpenPGP.ASCIIArmor.Types (Armor(..), ArmorType(..))
@@ -39,13 +39,12 @@ import Data.Conduit.OpenPGP.Filter (conduitPktFilter, FilterPredicates(RPFilterP
 import Data.Binary (get, put)
 import Data.Binary.Get (Get)
 import Data.Monoid ((<>))
-import Data.Version (showVersion)
 import Data.Void (Void)
 import qualified Data.Yaml as Y
 
-import System.IO (stdin, stderr, stdout, Handle, hFlush, hPutStrLn, hSetBuffering, BufferMode(..))
+import System.IO (stdin, stderr, stdout, Handle, hFlush, hSetBuffering, BufferMode(..))
 
-import Options.Applicative.Builder (argument, command, footerDoc, headerDoc, help, helpDoc, info, long, metavar, option, eitherReader, prefs, progDesc, showDefaultWith, showHelpOnError, str, strOption, value)
+import Options.Applicative.Builder (argument, command, eitherReader, footerDoc, headerDoc, help, helpDoc, info, long, metavar, option, prefs, progDesc, showDefaultWith, showHelpOnError, str, strOption, value)
 import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
 import Data.Text.Prettyprint.Doc ((<+>), group, hardline, list, Pretty, pretty, softline)
@@ -58,11 +57,6 @@ data DumpOptions = DumpOptions {
     outputformat :: DumpOutputFormat
 }
 
-data ArmoringOptions = ArmoringOptions {
-    comment :: Maybe String
-  , armortype :: ArmorType
-}
-
 data FilteringOptions = FilteringOptions {
     fExpression :: String
 }
@@ -90,30 +84,6 @@ jsonSink = CL.mapM_ (liftIO . BL.putStr . flip BL.snoc 0x0a . A.encode)
 yamlSink :: (Y.ToJSON a, MonadIO m) => ConduitM a Void m ()
 yamlSink = CL.mapM_ (liftIO . B.putStr . flip B.snoc 0x0a . Y.encode)
 
-doDeArmor :: IO ()
-doDeArmor = do
-    a <- runConduitRes $ CB.sourceHandle stdin .| CL.consume
-    case AA.decode (B.concat a) of
-        Left e -> hPutStrLn stderr $ "Failure to decode ASCII Armor:" ++ e
-        Right msgs -> BL.putStr $ BL.concat (map (\(Armor _ _ bs) -> bs) msgs)
-
-doArmor :: ArmoringOptions -> IO ()
-doArmor ArmoringOptions{..} = do
-    m <- runConduitRes $ CB.sourceHandle stdin .| CL.consume
-    let a = Armor armortype (("Version", "hot " ++ showVersion version):maybe [] (\x -> [("Comment", x)]) comment ) (BL.fromChunks m)
-    BL.putStr $ AA.encodeLazy [a]
-
-armorTypes :: [(String, ArmorType)]
-armorTypes = [
-    ("message", ArmorMessage)
-  , ("pubkeyblock", ArmorPublicKeyBlock)
-  , ("privkeyblock", ArmorPrivateKeyBlock)
-  , ("signature", ArmorSignature)
-  ]
-
-armorTypeReader :: String -> Either String ArmorType
-armorTypeReader = note "unknown armor type" . flip lookup armorTypes
-
 doFilter :: FilteringOptions -> IO ()
 doFilter fo = runConduitRes $ CB.sourceHandle stdin .| conduitGet (get :: Get Pkt) .| conduitPktFilter (parseExpressions fo) .| CL.map put .| conduitPut .| CB.sinkHandle stdout
 
@@ -129,13 +99,6 @@ doP = DumpOptions
         ofHelp = helpDoc . Just . toAnsiWlPprint $ pretty "output format" <> hardline <> list (map (pretty . drop 4 . show) ofchoices)
         ofchoices = [minBound..maxBound] :: [DumpOutputFormat]
 
-aoP :: Parser ArmoringOptions
-aoP = ArmoringOptions
-    <$> optional (strOption (long "comment" <> metavar "COMMENT" <> help "ASCII armor Comment field"))
-    <*> option (eitherReader armorTypeReader) (long "armor-type" <> metavar "ARMORTYPE" <> armortypeHelp)
-    where
-        armortypeHelp = helpDoc . Just . toAnsiWlPprint $ pretty "ASCII armor type" <> softline <> list (map (pretty . fst) armorTypes)
-
 foP :: Parser FilteringOptions
 foP = FilteringOptions
     <$> argument str ( metavar "EXPRESSION" <> filterTargetHelp )
@@ -174,3 +137,32 @@ parseExpressions :: FilteringOptions -> FilterPredicates
 parseExpressions FilteringOptions{..} = RPFilterPredicate (parseE fExpression)
     where
          parseE e = either (error . ("filter parse error: "++)) id (parsePExp e)
+
+armorTypes :: [(String, ArmorType)]
+armorTypes = [
+    ("message", ArmorMessage)
+  , ("pubkeyblock", ArmorPublicKeyBlock)
+  , ("privkeyblock", ArmorPrivateKeyBlock)
+  , ("signature", ArmorSignature)
+  ]
+
+armorTypeReader :: String -> Either String ArmorType
+armorTypeReader = note "unknown armor type" . flip lookup armorTypes
+
+aoP :: Parser ArmoringOptions
+aoP = ArmoringOptions
+    <$> optional (strOption (long "comment" <> metavar "COMMENT" <> help "ASCII armor Comment field"))
+    <*> option (eitherReader armorTypeReader) (long "armor-type" <> metavar "ARMORTYPE" <> armortypeHelp)
+    where
+        armortypeHelp = helpDoc . Just . toAnsiWlPprint $ pretty "ASCII armor type" <> softline <> list (map (pretty . fst) armorTypes)
+
+data ArmoringOptions = ArmoringOptions {
+    comment :: Maybe String
+  , armortype :: ArmorType
+}
+
+doArmor :: ArmoringOptions -> IO ()
+doArmor ArmoringOptions{..} = do
+    m <- runConduitRes $ CB.sourceHandle stdin .| CL.consume
+    let a = Armor armortype (maybe [] (\x -> [("Comment", x)]) comment) (BL.fromChunks m)
+    BL.putStr $ AA.encodeLazy [a]
